==> metamod-2.5.0.tar.gz: metamod-2.5.0/upload/htdocs/upl/BTN_retr_dir.php <==
<?php 
#---------------------------------------------------------------------------- 
#  METAMOD - Web portal for metadata search and upload 
# 
#  Copyright (C) 2008 met.no 
# 
#  Contact information: 
#  Norwegian Meteorological Institute 
#  Box 43 Blindern 
#  0313 OSLO 
#  NORWAY 
#  email: egil.storen@met.no 
#   
#  This file is part of METAMOD 
# 
#  METAMOD is free software; you can redistribute it and/or modify 
#  it under the terms of the GNU General Public License as published by 
#  the Free Software Foundation; either version 2 of the License, or 
#  (at your option) any later version. 
# 
#  METAMOD is distributed in the hope that it will be useful, 
#  but WITHOUT ANY WARRANTY; without even the implied warranty of 
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
#  GNU General Public License for more details. 
#   
#  You should have received a copy of the GNU General Public License 
#  along with METAMOD; if not, write to the Free Software 
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA 
#---------------------------------------------------------------------------- 
?>
<?php
 // The user has pushed the "Retrieve" button
 // in the Administration page
 //
 if ($debug) {
    mmPutTest("--------- User pushed Retrieve");
 }
 $nextpage = 3;
 check_credentials(); // Sets $error, $errmsg, $nextpage, $normemail, $sessioncode,
               // $runpath, $filepath, $dirinfo and $filecontent (globals).
 if ($error == 0) { // Check that institution exists and set $institution var.
    $userinfo = get_userinfo($filepath);
    if (!array_key_exists("institution",$userinfo)) {
       $error = 2;
       $nextpage = 1;
       mmPutLog('No institution in userinfo');
       $errmsg = "Sorry. Internal error";
    } else {
       $institution = $userinfo["institution"];
    }
 }
 if ($error == 0) {
    $dirname = conditional_decode($_POST["dirname"]);
    if (strlen($dirname) == 0) {
       // directory name can be in input or select box
       $dirname = conditional_decode($_POST["knownDirname"]);
    }
    if (strlen($dirname) == 0) {
#
# The user has pushed the Retrieve button with an empty directory name.
# Reload page to fill select box.
#
       $dirkey = "";
    } elseif (! array_key_exists($dirname,$dirinfo)) {
       $errmsg = "[Retrieve] failed. No such directory name";
       $error = 1;
       $nextpage = 3;
    } else {
       $dirattributes = $dirinfo[$dirname];
       foreach (array('key','location','catalog','wmsurl') as $k1) {
          if (array_key_exists($k1, $dirattributes)) {
             $val = decodenorm($dirattributes[$k1]);
             if ($k1 == 'key') {
                $dirkey = $val;
             } else if ($k1 == 'location') {
                $location = $val;
             } else if ($k1 == 'catalog') {
                $threddscatalog = $val;
             } else if ($k1 == 'wmsurl') {
                $wmsurl = $val;
             }
          }
       }
    }
 }
?>

==> metamod-2.6.0.tar.gz: metamod-2.6.0/upload/htdocs/upl/BTN_retr_dir.php <==
<?php 
#---------------------------------------------------------------------------- 
#  METAMOD - Web portal for metadata search and upload 
# 
#  Copyright (C) 2008 met.no 
# 
#  Contact information: 
#  Norwegian Meteorological Institute 
#  Box 43 Blindern 
#  0313 OSLO 
#  NORWAY 
#  email: egil.storen@met.no 
#   
#  This file is part of METAMOD 
# 
#  METAMOD is free software; you can redistribute it and/or modify 
#  it under the terms of the GNU General Public License as published by 
#  the Free Software Foundation; either version 2 of the License, or 
#  (at your option) any later version. 
# 
#  METAMOD is distributed in the hope that it will be useful, 
#  but WITHOUT ANY WARRANTY; without even the implied warranty of 
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
#  GNU General Public License for more details. 
#   
#  You should have received a copy of the GNU General Public License 
#  along with METAMOD; if not, write to the Free Software 
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA 
#---------------------------------------------------------------------------- 
?>
<?php
 // The user has pushed the "Retrieve" button
 // in the Administration page
 //
 if ($debug) {
    mmPutTest("--------- User pushed Retrieve");
 }
 $nextpage = 3;
 check_credentials(); // Sets $error, $errmsg, $nextpage, $normemail, $sessioncode,
               // $runpath, $filepath, $dirinfo and $filecontent (globals).
 if ($error == 0) { // Check that institution exists and set $institution var.
    $userinfo = get_userinfo($filepath);
    if (!array_key_exists("u_institution",$userinfo)) {
       $error = 2;
       $nextpage = 1;
       mmPutLog('No u_institution in userinfo');
       $errmsg = "Sorry. Internal error";
    } else {
       $institution = $userinfo["u_institution"];
    }
 }
 if ($error == 0) {
    $dirname = conditional_decode($_POST["dirname"]);
    if (strlen($dirname) == 0) {
       // directory name can be in input or select box
       $dirname = conditional_decode($_POST["knownDirname"]);
    }
    if (strlen($dirname) == 0) {
#
# The user has pushed the Retrieve button with an empty directory name.
# Reload page to fill select box.
#
       $dirkey = "";
    } elseif (! array_key_exists($dirname,$dirinfo)) {
       $errmsg = "[Retrieve] failed. No such directory name";
       $error = 1;
       $nextpage = 3;
    } else {
       $dirattributes = $dirinfo[$dirname];
       foreach (array('DSKEY','LOCATION','CATALOG','WMS_URL','WMS_XML') as $k1) {
          if (array_key_exists($k1, $dirattributes)) {
             $val = $dirattributes[$k1];
             if ($k1 == 'DSKEY') {
                $dirkey = $val;
             } else if ($k1 == 'LOCATION') {
                $location = $val;
             } else if ($k1 == 'CATALOG') {
                $threddscatalog = $val;
             } else if ($k1 == 'WMS_URL') {
                $wmsurl = $val;
             }
          }
       }
    }
 }
?>
